consul

package
v0.0.0-...-df79ff2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 4, 2018 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ErrInvalidRevocation is returned if the revocation data is malformed
	ErrInvalidRevocation = errors.New("invalid revocation data")
)

Functions

This section is empty.

Types

type Engine

type Engine struct {
	Address string
	Scheme  string
	Token   string

	TokenType string
	Policy    string
}

Engine is a Consul secrets engine that can provision and revoke credentials.

func (*Engine) Provision

func (e *Engine) Provision(ctx context.Context, namespace, name string) ([]byte, map[string][]byte, error)

Provision provisions credentials using the engine configuration.

func (*Engine) Revoke

func (e *Engine) Revoke(ctx context.Context, revocation []byte) error

Revoke revokes credentials using the engine configuration.

Jump to